Prime meridian - Wikipedia

# Prime meridian

From Wikipedia, the free encyclopedia
"Prime Meridian" redirects here. For the meridian often called the Prime Meridian, see Prime meridian (Greenwich).
0°
Prime Meridian

A prime meridian is a meridian (a line of longitude) in a geographical coordinate system at which longitude is defined to be 0°. Together, a prime meridian and its antimeridian (the 180th meridian in a 360°-system) form a great circle. This great circle divides the sphere, e.g., the Earth, into two hemispheres. If one uses directions of East and West from a defined prime meridian, then they can be called Eastern Hemisphere and Western Hemisphere.

Gerardus Mercator in his Atlas Cosmographicae (1595) uses a prime meridian somewhere close to 25°W, passing just to the west of Santa Maria Island in the Atlantic. His 180th meridian runs along the Strait of Anián (Bering Strait)

A prime meridian is ultimately arbitrary, unlike an equator, which is determined by the axis of rotation—and various conventions have been used or advocated in different regions and throughout history.[1]

## History[edit]

See also: History of longitude
Ptolemy's 1st projection, redrawn under Maximus Planudes around 1300, using a prime meridian east of Africa

The notion of longitude was developed by the Greek Eratosthenes (c. 276 BC – c. 195 BC) in Alexandria and Hipparchus (c. 190 BC – c. 120 BC) in Rhodes and applied to a large number of cities by the geographer Strabo (64/63 BC – c. 24 AD). But it was Ptolemy (c. AD 90 – c. AD 168) who first used a consistent meridian for a world map in his Geographia.

Ptolemy used as his basis the "Fortunate Isles", a group of islands in the Atlantic which are usually associated with the Canary Islands (13° to 18°W), although his maps correspond more closely to the Cape Verde islands (22° to 25° W). The main point is to be comfortably west of the western tip of Africa (17.5° W) as negative numbers were not yet in use. His prime meridian corresponds to 18° 40' west of Winchester (about 20°W) today.[2] At this time the chief method of determining longitude was by using the reported times of lunar eclipses in different countries.

Diogo Ribeiro's map of 1529, now in the Vatican library

Ptolemy's Geographia was first printed with maps at Bologna in 1477 and many early globes in the sixteenth century followed his lead. But there was still a hope that a "natural" basis for a prime meridian existed. Christopher Columbus reported (1493) that the compass pointed due north somewhere in mid-Atlantic and this fact was used in the important Tordesillas Treaty of 1494 which settled the territorial dispute between Spain and Portugal over newly discovered lands. The Tordesillas line was eventually settled at 370 leagues west of Cape Verde. This is shown in Diogo Ribeiro's 1529 map. São Miguel Island (25.5°W) in the Azores was still used for the same reason as late as 1594 by Christopher Saxton, although by this time it had been shown that the zero deviation line did not follow a line of longitude.[3]

1571 Africa map by Abraham Ortelius, Cabo Verde prime meridian

In 1541, Mercator produced his famous forty-one centimetre terrestrial globe and drew his prime meridian precisely through Fuertaventura (14°1'W) in the Canaries. His later maps used the Azores, following the magnetic hypothesis. But by the time that Ortelius produced the first modern atlas in 1570, other islands such as Cape Verde were coming into use. In his atlas longitudes were counted from 0° to 360°, not 180°W to 180°E as is common today. This practice was followed by navigators well into the eighteenth century.[4] In 1634, Cardinal Richelieu used the westernmost island of the Canaries, Ferro, 19° 55' west of Paris, as the choice of meridian. Unfortunately, the geographer Delisle decided to round this off to 20°, so that it simply became the meridian of Paris disguised.[5]

In the early eighteenth century the battle was on to improve the determination of longitude at sea, leading to the development of the chronometer by John Harrison. But it was the development of accurate star charts principally by the first British Astronomer Royal, John Flamsteed between 1680 and 1719 and disseminated by his successor, Edmund Halley that enabled navigators to use the lunar method of determining longitude more accurately using the octant developed by Thomas Godfrey and John Hadley.[6] Between 1765 and 1811, Nevil Maskelyne published 49 issues of the Nautical Almanac based on the meridian of the Royal Observatory, Greenwich. "Maskelyne's tables not only made the lunar method practicable, they also made the Greenwich meridian the universal reference point. Even the French translations of the Nautical Almanac retained Maskelyne's calculations from Greenwich—in spite of the fact that every other table in the Connaissance des Temps considered the Paris meridian as the prime." [7]

In 1884, at the International Meridian Conference held in Washington, D.C., 22 countries voted to adopt the Greenwich[8] meridian as the prime meridian of the world. The French argued for a neutral line, mentioning the Azores and the Bering Strait but eventually abstained and continued to use the Paris meridian until 1911.

## List of prime meridians on Earth[edit]

Locality | GPS longitude | Meridian name | Comment
--- | --- | --- | ---
Bering Strait | 168°30′ W |  | Bering Strait offered 1884 as possibility for a "neutral prime meridian" by Pierre Janssen at the International Meridian Conference [9]
Washington, D.C. | 77°03′56.07″ W (1897) or 77°04′02.24″ W (NAD 27) or 77°04′01.16″ W (NAD 83) | New Naval Observatory meridian |
Washington, D.C. | 77°02′48.0″ W, 77°03′02.3″, 77°03′06.119″ W or 77°03′06.276″ W (both presumably NAD 27). If NAD27, the latter would be 77°03′05.194″ W (NAD 83) | Old Naval Observatory meridian |
Washington, D.C. | 77°02′11.56258″ W (NAD 83), 77°02′11.55880″ W (NAD 83), 77°02′11.57375″ W (NAD 83) | White House meridian |
Washington, D.C. | 77°00′32.6″ W (NAD 83) | Capitol meridian |
Philadelphia | 75° 10′ 12″ W |  | [10][11]
Rio de Janeiro | 43° 10′ 19″ W |  | [12]
Fortunate Isles / Azores | 25° 40′ 32″ W |  | Used until the Middle Ages, proposed as one possible neutral meridian by Pierre Janssen at the International Meridian Conference[13]
El Hierro (Ferro), Canary Islands | 18° 03′ W, later redefined as 17° 39′ 46″ W | Ferro meridian | [14]
Tenerife | 16° 38' 22" W | Tenerife meridian | Rose to prominence with Dutch cartographers and navigators after they abandoned the idea of a magnetic meridian[15]
Lisbon | 9° 07′ 54.862″ W |  | [16]
Madrid | 3° 41′ 16.58″ W |  | [16]
Greenwich | 0° 00′ 05.3101″ W | Greenwich meridian | Airy Meridian[17]
Greenwich | 0° 00′ 05.33″ W | United Kingdom Ordnance Survey Zero Meridian | Bradley Meridian[17]
Greenwich | 0° 00′ 00.00″ | IERS Reference Meridian |
Paris | 2° 20′ 14.025″ E | Paris meridian |
Brussels | 4° 22′ 4.71″ E |  | [16]
Antwerp | 4° 24′ E | Antwerp meridian | [citation needed]
Amsterdam | 4° 53′ E |  | through the Westerkerk in Amsterdam; used to define the legal time in the Netherlands from 1909 to 1937[18]
Bern | 7° 26′ 22.5″ E |  | [citation needed]
Pisa | 10° 24′ E |  | [10]
Oslo (Kristiania) | 10° 43′ 22.5″ E |  | [10][11]
Florence | 11°15′ E | Florence meridian | used in the Peters projection, antipode of a line running through the Bering Strait
Rome | 12° 27′ 08.4″ E | meridian of Monte Mario | Used in Roma 40 Datum [19]
Copenhagen | 12° 34′ 32.25″ E |  | Rundetårn[20]
Naples | 14° 15′ E |  | [13]
Stockholm | 18° 03′ 29.8″ E |  | at the Stockholm Observatory[16]
Krakow | 19° 57′ 21.43″ E | Krakow meridian | at the Old Krakow Observatory at the Śniadecki' College mentioned also in Nikolas Copernicus' work "On the Revolutions of the Heavenly Spheres".
Warsaw | 21° 00′ 42″ E | Warsaw meridian | [16]
Oradea | 21° 55′ 16″ E |  | [21]
Alexandria | 29° 53′ E |  | [22]
Saint Petersburg | 30° 19′ 42.09″ E | Pulkovo meridian |
Great Pyramid of Giza | 31° 08′ 03.69″ E |  | 1884 [23]
Jerusalem | 35° 13′ 47.1″ E |  | [11]
Mecca | 39° 49′ 34″ E |  | see also Mecca Time [24]
Ujjain | 75° 47′ E |  | Used from 4th century CE Indian astronomy and calendars(see also Time in India).[25]
Kyoto | 136° 14′ E |  | Used in 18th and 19th (officially 1779–1871) century Japanese maps. Exact place unknown, but in "Kairekisyo" in Nishigekkoutyou-town in Kyoto, then the capital.[citation needed]
| ~ 180 |  | Opposite of Greenwich, proposed 13 October 1884 on the International Meridian Conference by Sandford Fleming [13]

## International prime meridian[edit]

In October 1884 the Greenwich Meridian was selected by delegates (forty-one delegates representing twenty-five nations) to the International Meridian Conference held in Washington, D.C., United States to be the common zero of longitude and standard of time reckoning throughout the world.[26][note 1] The modern prime meridian, the IERS Reference Meridian, is placed very near this meridian and is the prime meridian that currently has the widest use.

### Prime meridian at Greenwich[edit]

Markings of the prime meridian at the Royal Observatory, Greenwich.
Main article: Prime Meridian (Greenwich)

The modern prime meridian, based at the Royal Observatory, Greenwich, was established by Sir George Airy in 1851.[28]

The position of the Greenwich Meridian has been defined by the location of the Airy Transit Circle ever since the first observation was taken with it by Sir George Airy in 1851.[28] Prior to that, it was defined by a succession of earlier transit instruments, the first of which was acquired by the second Astronomer Royal, Edmond Halley in 1721. It was set up in the extreme north-west corner of the Observatory between Flamsteed House and the Western Summer House. This spot, now subsumed into Flamsteed House, is roughly 43 metres to the west of the Airy Transit Circle, a distance equivalent to roughly 0.15 seconds of time.[17] It was Airy's transit circle that was adopted in principle (with French delegates, who pressed for adoption of the Paris meridian abstaining) as the Prime Meridian of the world at the 1884 International Meridian Conference.[29][30]

All of these Greenwich meridians were located via an astronomic observation from the surface of the Earth, oriented via a plumb line along the direction of gravity at the surface. This astronomic Greenwich meridian was disseminated around the world, first via the lunar distance method, then by chronometers carried on ships, then via telegraph lines carried by submarine communications cables, then via radio time signals. One remote longitude ultimately based on the Greenwich meridian using these methods was that of the North American Datum 1927 or NAD27, an ellipsoid whose surface best matches mean sea level under the United States.

### IERS Reference Meridian[edit]

Main article: IERS Reference Meridian

Satellites changed the reference from the surface of the Earth to its centre of mass around which all satellites orbit regardless of surface irregularities. The requirement that satellite-based geodetic reference systems be centred on the centre of mass of the earth caused the modern prime meridian to be 5.3" east of the astronomic Greenwich prime meridian through the Airy Transit Circle. At the latitude of Greenwich, this amounts to 102 metres.[31] This was officially accepted by the Bureau International de l'Heure (BIH) in 1984 via its BTS84 (BIH Terrestrial System) that later became WGS84 (World Geodetic System 1984) and the various ITRFs (International Terrestrial Reference Systems).

Due to the movement of Earth's tectonic plates, the line of 0° longitude along the surface of the Earth has slowly moved toward the west from this shifted position by a few centimetres; that is, towards the Airy Transit Circle (or the Airy Transit Circle has moved toward the east, depending on your point of view) since 1984 (or the 1960s). With the introduction of satellite technology, it became possible to create a more accurate and detailed global map. With these advances there also arose the necessity to define a reference meridian that, whilst being derived from the Airy Transit Circle, would also take into account the effects of plate movement and variations in the way that the Earth was spinning.[32] As a result, the International Reference Meridian was established and is commonly used to denote Earth's prime meridian (0° longitude) by the International Earth Rotation and Reference Systems Service, which defines and maintains the link between longitude and time. Based on observations to satellites and celestial compact radio sources (quasars) from various coordinated stations around the globe, Airy's transit circle drifts northeast about 2.5 centimetres per year relative to this Earth-centred 0° longitude. Circa 1999 the international reference meridian (IRM) passed 5.31 arcseconds east of Airy's meridian or 102.5 metres (336.3 feet) at the latitude of the Royal Observatory, Greenwich, London.[33][34][35][36] It is also the reference meridian of the Global Positioning System operated by the United States Department of Defense, and of WGS84 and its two formal versions, the ideal International Terrestrial Reference System (ITRS) and its realization, the International Terrestrial Reference Frame (ITRF).[33][34][35] A current convention on the Earth uses the opposite of the IRM as the basis for the International Date Line.

#### List of places[edit]

Map all coordinates using OSM Map all coordinates using Google Map up to 200 coordinates using Bing
Export all coordinates as KML
Export all coordinates as GeoRSS
Export all coordinates as GPX
Map all microformatted coordinates
Place data as RDF

On Earth, starting at the North Pole and heading south to the South Pole, the IERS Reference Meridian (as of 2016) passes through:

  Co-ordinates (approximate) | Country, territory or sea | Notes
  --- | --- | ---
  90°0′N 0°0′E﻿ / ﻿90.000°N 0.000°E﻿ / 90.000; 0.000﻿ (North Pole) | Arctic Ocean |
  81°39′N 0°0′E﻿ / ﻿81.650°N 0.000°E﻿ / 81.650; 0.000﻿ (Greenland Sea) | Greenland Sea |
  72°53′N 0°0′E﻿ / ﻿72.883°N 0.000°E﻿ / 72.883; 0.000﻿ (Norwegian Sea) | Norwegian Sea |
  61°0′N 0°0′E﻿ / ﻿61.000°N 0.000°E﻿ / 61.000; 0.000﻿ (North Sea) | North Sea |
  53°45′N 0°0′E﻿ / ﻿53.750°N 0.000°E﻿ / 53.750; 0.000﻿ (United Kingdom) | United Kingdom | From Tunstall in East Riding to Peacehaven, passing through Greenwich
  50°47′N 0°0′E﻿ / ﻿50.783°N 0.000°E﻿ / 50.783; 0.000﻿ (English Channel) | English Channel |
  49°19′N 0°0′E﻿ / ﻿49.317°N 0.000°E﻿ / 49.317; 0.000﻿ (France) | France | From Villers-sur-Mer to Gavarnie
  42°41′N 0°0′E﻿ / ﻿42.683°N 0.000°E﻿ / 42.683; 0.000﻿ (Spain) | Spain | From Cilindro de Marboré to Castellón de la Plana
  39°56′N 0°0′E﻿ / ﻿39.933°N 0.000°E﻿ / 39.933; 0.000﻿ (Mediterranean Sea) | Mediterranean Sea | Gulf of Valencia
  38°52′N 0°0′E﻿ / ﻿38.867°N 0.000°E﻿ / 38.867; 0.000﻿ (Spain) | Spain | From El Verger to Calpe
  38°38′N 0°0′E﻿ / ﻿38.633°N 0.000°E﻿ / 38.633; 0.000﻿ (Mediterranean Sea) | Mediterranean Sea |
  35°50′N 0°0′E﻿ / ﻿35.833°N 0.000°E﻿ / 35.833; 0.000﻿ (Algeria) | Algeria | From Stidia to Algeria-Mali border near Bordj Mokhtar
  21°50′N 0°0′E﻿ / ﻿21.833°N 0.000°E﻿ / 21.833; 0.000﻿ (Mali) | Mali |
  14°59′N 0°0′E﻿ / ﻿14.983°N 0.000°E﻿ / 14.983; 0.000﻿ (Burkina Faso) | Burkina Faso |
  11°6′N 0°0′E﻿ / ﻿11.100°N 0.000°E﻿ / 11.100; 0.000﻿ (Togo) | Togo | For about 600 m
  11°6′N 0°0′E﻿ / ﻿11.100°N 0.000°E﻿ / 11.100; 0.000﻿ (Ghana) | Ghana | For about 16 km
  10°57′N 0°0′E﻿ / ﻿10.950°N 0.000°E﻿ / 10.950; 0.000﻿ (Togo) | Togo | For about 39 km
  10°36′N 0°0′E﻿ / ﻿10.600°N 0.000°E﻿ / 10.600; 0.000﻿ (Ghana) | Ghana | From the Togo-Ghana border near Bunkpurugu to Tema Passing through Lake Volta at 7°48′N 0°0′E﻿ / ﻿7.800°N 0.000°E﻿ / 7.800; 0.000﻿ (Lake Volta)
  5°37′N 0°0′E﻿ / ﻿5.617°N 0.000°E﻿ / 5.617; 0.000﻿ (Atlantic Ocean) | Atlantic Ocean | Passing through the Equator at 0°0′N 0°0′E﻿ / ﻿0.000°N 0.000°E﻿ / 0.000; 0.000﻿ (Equator)
  60°0′S 0°0′E﻿ / ﻿60.000°S 0.000°E﻿ / -60.000; 0.000﻿ (Southern Ocean) | Southern Ocean |
  68°54′S 0°0′E﻿ / ﻿68.900°S 0.000°E﻿ / -68.900; 0.000﻿ (Antarctica) | Antarctica | Queen Maud Land, claimed by Norway

## Prime meridian on other planetary bodies[edit]

See also: Longitude (planets)
"Prime meridian (planets)" redirects here. It is not to be confused with Central meridian (planets).

As on the Earth, prime meridians must be arbitrarily defined. Often a landmark such as a crater is used; other times a prime meridian is defined by reference to another celestial object, or by magnetic fields. The prime meridians of the following planetographic systems have been defined:

- Two different heliographic coordinate systems are used on the Sun. The first is the Carrington heliographic coordinate system. In this system, the prime meridian passes through the center of the solar disk as seen from the Earth on 9 November 1853, which is when Richard Christopher Carrington started his observations of sunspots.[37] The second is the Stonyhurst heliographic coordinates system.
- The prime meridian of Mercury is defined to be 20° west of the crater Hun Kal.[38]
- The prime meridian of Venus passes through the central peak in the crater Ariadne.[39]
- The prime meridian of the Moon lies directly in the middle of the face of the moon visible from Earth and passes near the crater Bruce.
- The prime meridian of Mars is defined by the crater Airy-0.
- Jupiter has several coordinate systems because its cloud tops—the only part of the planet visible from space—rotate at different rates depending on latitude.[40] It is unknown whether Jupiter has any internal solid surface that would enable a more Earth-like coordinate system. System I and System II coordinates are based on atmospheric rotation, and System III coordinates use Jupiter's magnetic field.
- Titan, like the Earth's moon, always has the same face towards Saturn, and so the middle of that face is 0 longitude.
- Pluto's prime meridian is defined as the center of the face that is always pointed towards Charon, its largest moon, as the two are tidally locked towards each other.

## See also[edit]

- 1st meridian east
- 1st meridian west

## Notes[edit]

1. ^ Voting took place on 13 October and the resolutions were adopted on 22 October 1884.[27]

## References[edit]

1. ^ Prime Meridian, geog.port.ac.uk
2. ^ Norgate 2006
3. ^ Hooker 2006
4. ^ e.g. Jacob Roggeveen in 1722 reported the longitude of Easter Island as 268° 45' (starting from Fuertaventura) in the Extract from the Official log of Jacob Roggeveen reproduced in Bolton Glanville Corney, ed. (1908), The voyage of Don Felipe Gonzalez to Easter Island in 1770-1, Hakluyt Society, p. 3, retrieved 13 January 2013
5. ^ Speech by Pierre Janssen, director of the Paris observatory, at the first session of the Meridian Conference.
6. ^ Sobel & Andrewes 1998, pp. 110–115
7. ^ Sobel & Andrewes 1998, pp. 197–199
8. ^ "The Prime Meridian at Greenwich". Royal Museums Greenwich. n.d. Retrieved 28 March 2016.
9. ^ International Conference Held at Washington for the Purpose of Fixing a Prime Meridian and a Universal Day. October, 1884. Project Gutenberg
10. ^ a b c Hooker (2006), introduction.
11. ^ a b c Oct. 13, 1884: Greenwich Resolves Subprime Meridian Crisis, WIRED, 13 October 2010.
12. ^ Atlas do Brazil, 1909, by Barão Homem de Mello e Francisco Homem de Mello, published in Rio de Janeiro by F. Briguiet & Cia.
13. ^ a b c "The Project Gutenberg eBook of International Conference Held at Washington for the Purpose of Fixing a Prime Meridian and a Universal Day". Gutenberg.org. 12 February 2006. Retrieved 28 March 2016.
14. ^ Ancient, used in Ptolemy's Geographia. Later redefined 17° 39′ 46″ W of Greenwich to be exactly 20° W of Paris. French "submarin" at Washington 1884.
15. ^ A.R.T. Jonkers; Parallel meridians: Diffusion and change in early modern oceanic reckoning, in Noord-Zuid in Oostindisch perspectief, The Hague, 2005, p. 7. Retrieved 2 February 2015.
16. ^ a b c d e Bartky, Ian R. (2007), One Time Fits All: The Campaigns for Global Uniformity, p. 98, retrieved through GoogleBooks, 6 May 2014.
17. ^ a b c Dolan 2013a.
18. ^ (Dutch)Eenheid van tijd in Nederland (Unity of time in the Netherlands), Utrecht University website, retrieved 28 August 2013.
19. ^ Grids & Datums – Italian Republic, asprs.org, Retrieved 10 December 2013.
20. ^ meridian, article from Den Store Danske Encyklopædi
21. ^ Oradea, Tourism office website, retrieved 3 February 2015.
22. ^ The meridian of Ptolemy's Almagest.
23. ^ Wilcomb E. Washburn, "The Canary Islands and the Question of the Prime Meridian: The Search for Precision in the Measurement of the Earth"
24. ^ Maimonides, Hilchot Kiddush Hachodesh 11:17, calls this point אמצע היישוב, "the middle of the habitation", i.e. the habitable hemisphere. Evidently this was a convention accepted by Arab geographers of his day.
25. ^ Burgess c. 2013
26. ^ "International Conference Held at Washington for the Purpose of Fixing a Prime Meridian and a Universal Day. October, 1884. Protocols of the proceedings". Project Gutenberg. 1884. Retrieved 30 November 2012.
27. ^ Howse 1997, pp. 12, 137
28. ^ a b Greenwich Observatory ... the story of Britain's oldest scientific institution, the Royal Observatory at Greenwich and Herstmonceux, 1675–1975 p.10. Taylor & Francis, 1975
29. ^ McCarthy, Dennis; Seidelmann, P. Kenneth (2009). TIME from Earth Rotation to Atomic Physics. Weinheim: Wiley-VCH. pp. 244–5.
30. ^ ROG Learing Team (23 August 2002). "The Prime Meridian at Greenwich". Royal Museums Greenwich. Royal Museums Greenwich. Retrieved 14 June 2012.
31. ^ Malys, Stephen; Seago, John H.; Palvis, Nikolaos K.; Seidelmann, P. Kenneth; Kaplan, George H. (1 August 2015). "Why the Greenwich meridian moved". Journal of Geodesy. Bibcode:2015JGeod..89.1263M. doi:10.1007/s00190-015-0844-y.
32. ^ Dolan 2013b.
33. ^ a b History of the Prime Meridian -Past and Present
34. ^ a b IRM on grounds of Royal Observatory from Google Earth Accessed 30 March 2012
35. ^ a b The astronomic latitude of the Royal Observatory is 51°28'38"N whereas its latitude on the European Terrestrial Reference Frame (1989) datum is 51°28'40.1247"N.
36. ^ Guinot, B., 2011. Solar time, legal time, time in use. Metrologica 48, S181–S185.
37. ^ "Carrington heliographic coordinates".
38. ^ Archinal, B. A.; A’Hearn, M. F.; Bowell, E.; Conrad, A.; Consolmagno, G. J.; Courtin, R.; Fukushima, T.; Hestroffer, D.; Hilton, J. L.; Krasinsky, G. A.; Neumann, G.; Oberst, J.; Seidelmann, P. K.; Stooke, P.; Tholen, D. J.; Thomas, P. C.; Williams, I. P. (23 October 2010). "Report of the IAU Working Group on Cartographic Coordinates and Rotational Elements: 2009" (PDF). Celestial Mechanics and Dynamical Astronomy: 15. doi:10.1007/s10569-010-9320-4.
39. ^ "USGS Astrogeology: Rotation and pole position for the Sun and planets (IAU WGCCRE)". Retrieved 22 October 2009.
40. ^ "Planetographic Coordinates". Retrieved 19 June 2009.

- Burgess, Ebenezer (1860), "Translation of the Surya-Siddhanta", Journal of the American Oriental Society (e book), 6, Google (published c. 2013), p. 185

- Dolan, Graham (2013a). "The Greenwich Meridian before the Airy Transit Circle". The Greenwich Meridian.

- Dolan, Graham (2013b). "WGS84 and the Greenwich Meridian". The Greenwich Meridian.

## Further reading[edit]

- Hooker, Brian (2006), A multitude of prime meridians, retrieved 13 January 2013
- Norgate, Jean and Martin (2006), Prime meridian, retrieved 13 January 2013
- Sobel, Dava; Andrewes, William J. H. (1998), The Illustrated Longitude, Fourth Estate, London
- Howse, Derek (1997), Greenwich Time and the Longitude, Phillip Wilson, ISBN 0-85667-468-0

## External links[edit]

| Wikimedia Commons has media related to Prime meridian.

- "Where the Earth's surface begins—and ends", Popular Mechanics, December 1930
- scanned TIFFs of the conference proceedings
- Prime meridians in use in the 1880s, by country

Retrieved from "https://en.wikipedia.org/w/index.php?title=Prime_meridian&oldid=746362704"
Categories:

- Geodesy
- Lines of longitude

Hidden categories:

- Articles with Dutch-language external links
- Use dmy dates from March 2016
- All articles with unsourced statements
- Articles with unsourced statements from February 2015
- Articles with unsourced statements from July 2013
- Lists of coordinates
- Geographic coordinate lists
- Articles with Geo
- Commons category with local link same as on Wikidata